Learn R Programming

parsermd (version 0.1.3)

parsermd-package: parsermd: Formal Parser and Related Tools for R Markdown Documents

Description

An implementation of a formal grammar and parser for R Markdown documents using the Boost Spirit X3 library. It also includes a collection of high level functions for working with the resulting abstract syntax tree.

Arguments

Author

Maintainer: Colin Rundel rundel@gmail.com

See Also