Section reference selectors
Section reference selectors are a simplified version of CSS selectors that
are designed to enable the selection nodes in a way that respects the implied
hierarchy of a document's section headings.
They consist of a character vector of heading names where each subsequent value
is assumed to be nested within the preceding value. For example, the section
selector c("Sec 1", "Sec 2") would select all nodes that are contained within
a section named Sec 2 that is in turn contained within a section named Sec 1
(or a section contained within a section named Sec 1, and so on).
The individual section names can be specified using wildcards (aka globbing
patterns), which may match one or more sections within the document, e.g.
c("Sec 1", "Sec *"). See utils::glob2rx() or
wikipedia
for more details on the syntax for these patterns.